# Data License

## Station Database (`radio_stations.db`)

The station database is licensed under the **Open Database License (ODbL) v1.0**.

### You are free to:

- **Share** — copy, distribute and use the database
- **Create** — produce works from the database
- **Adapt** — modify, transform and build upon the database

### Under the following conditions:

- **Attribution** — You must attribute any public use of the database, or works produced from the database, by citing the source (see ATTRIBUTION.md)
- **Share-Alike** — If you publicly use any adapted version of this database, you must also offer that adapted database under the ODbL
- **Keep open** — If you redistribute the database or an adapted version of it, you must make the database available without technological restrictions

### Full License Text

https://opendatacommons.org/licenses/odbl/1.0/

---

## Metadata & Analytics

Song play events, listening patterns, trend analysis, and other analytics derived from real-time stream observation are **independently collected data** and are not subject to ODbL.

These datasets are owned by the radiomcp project and may be licensed separately.

---

## Code License

The source code (Python files, documentation) is licensed under the **MIT License**. See LICENSE file.
